/*
Continuous Testing Toolkit
Copyright (C) 2009 Paul R. Holser, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.infinitest.toolkit;

import static org.apache.commons.lang.exception.ExceptionUtils.*;
import static org.junit.Assert.*;

/**
 * Assertions for use in JUnit tests.
 *
 * @author <a href="http://www.pholser.com">Paul Holser</a>
 */
public class Assertions {
    static {
        new Assertions();
    }

    private Assertions() {
        // nothing to do here
    }

    /**
     * Tests that the given block raises no exception.
     *
     * @param block the block to execute
     * @throws AssertionError if the block raises any exception
     */
    public static void assertNoException(Block block) {
        try {
            block.execute();
        }
        catch (Exception e) {
            fail("expected no exception, but got " + e.getMessage() + '\n' + getFullStackTrace(e));
        }
    }
}
