/*
Continuous Testing Toolkit
Copyright (C) 2009 Paul R. Holser, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.infinitest.toolkit;

import java.util.regex.Pattern;

import org.hamcrest.BaseMatcher;
import org.hamcrest.Description;
import org.hamcrest.Matcher;

/**
 * <a href="http://code.google.com/p/hamcrest/">Hamcrest</a> matcher that verifies that strings match regular
 * expressions.
 *
 * @author <a href="http://www.pholser.com">Paul Holser</a>
 */
public class RegexMatcher extends BaseMatcher<String> {
    private final Pattern regex;

    private RegexMatcher(String regex) {
        this.regex = Pattern.compile(regex);
    }

    public boolean matches(Object toMatch) {
        return regex.matcher((String) toMatch).matches();
    }

    public void describeTo(Description description) {
        description.appendText("Pattern didn't match: " + regex.pattern());
    }

    public static Matcher<String> matchesRegex(String regex) {
        return new RegexMatcher(regex);
    }
}
