/*
Continuous Testing Toolkit
Copyright (C) 2009 Paul R. Holser, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.infinitest.toolkit;

import java.io.Serializable;

import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.*;
import static org.apache.commons.lang.SerializationUtils.*;

/**
 * Support structure for testing the {@linkplain Serializable serializability} of instances of a class.
 *
 * @author <a href="http://www.pholser.com">Paul Holser</a>
 */
public abstract class SerializabilityTestSupport {
    private Serializable object;

    protected abstract Serializable instance() throws Exception;

    @Before
    public final void initializeHarness() throws Exception {
        object = instance();

        assertNotNull("instance() returned null", object);
    }

    @Test
    public final void shouldSerializeAndDeserializeWithoutErrorPreservingFields() {
        byte[] serialized = serialize(object);
        Serializable deserialized = (Serializable) deserialize(serialized);

        checkThawedObject(object, deserialized);
    }

    /**
     * Performs checks on the deserialized form of the object serialized in {@link #testSerializability}. By default,
     * this asserts that the pre-serialization and deserialized forms of the object compare equal via
     * {@link java.lang.Object#equals(Object) equals}.
     *
     * @param expected
     *            the pre-serialization form of the object
     * @param actual
     *            the deserialized form of the object
     */
    protected void checkThawedObject(Serializable expected, Serializable actual) {
        assertEquals("thawed object comparison", expected, actual);
    }
}
