/*
Continuous Testing Toolkit
Copyright (C) 2009 Paul R. Holser, Jr.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.infinitest.toolkit;

import java.util.Collection;
import java.util.List;
import java.util.ListIterator;

import org.junit.Test;

/**
 * Support structure for testing the {@linkplain java.util.Collections#unmodifiableList(List) unmodifiability} of a
 * list. This is useful for verifying that accessor methods that return lists do not allow direct adding or removing
 * from the underlying list field.
 *
 * @param <T> the type of the items in the lists involved
 * @author <a href="http://www.pholser.com">Paul Holser</a>
 */
public abstract class UnmodifiableListTestSupport<T> extends UnmodifiableCollectionTestSupport<T> {
    @Test(expected = UnsupportedOperationException.class)
    public final void shouldPreventAddAtIndex() {
        list().add(0, newItem());
    }

    @Test(expected = UnsupportedOperationException.class)
    public final void shouldPreventRemoveAtIndex() {
        list().remove(0);
    }

    @Test(expected = UnsupportedOperationException.class)
    public final void shouldPreventSetAtIndex() {
        list().set(0, newItem());
    }

    @Test(expected = UnsupportedOperationException.class)
    public final void shouldPreventRemoveViaListIterator() {
        ListIterator<T> iter = list().listIterator();
        iter.next();
        iter.remove();
    }

    @Test(expected = UnsupportedOperationException.class)
    public final void shouldPreventSetViaListIterator() {
        ListIterator<T> iter = list().listIterator();
        iter.next();
        iter.set(newItem());
    }

    @Override
    protected final Collection<T> newCollection() {
        return newList();
    }

    /**
     * @return a list to test for unmodifiability
     */
    protected abstract List<T> newList();

    private List<T> list() {
        return (List<T>) items;
    }
}
